==> apache-cxf-3.6.6-src.zip: apache-cxf-3.6.6-src/rt/ws/eventing/src/test/java/org/apache/cxf/ws/eventing/base/services/TestingSubscriptionManager.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.ws.eventing.base.services;

import javax.jws.WebService;

import org.apache.cxf.ws.eventing.backend.manager.SubscriptionManagerInterfaceForManagers;
import org.apache.cxf.ws.eventing.base.SingletonSubscriptionManagerContainer;
import org.apache.cxf.ws.eventing.manager.AbstractSubscriptionManager;



/**
 * Simple Subscription Manager webservice for integration tests
 */
@WebService(endpointInterface = "org.apache.cxf.ws.eventing.manager.SubscriptionManagerEndpoint")
public class TestingSubscriptionManager extends AbstractSubscriptionManager {

    @Override
    protected SubscriptionManagerInterfaceForManagers getSubscriptionManagerBackend() {
        return SingletonSubscriptionManagerContainer.getInstance();
    }

}

==> apache-cxf-4.0.10-src.zip: apache-cxf-4.0.10-src/rt/ws/eventing/src/test/java/org/apache/cxf/ws/eventing/base/services/TestingSubscriptionManager.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.ws.eventing.base.services;

import jakarta.jws.WebService;
import org.apache.cxf.ws.eventing.backend.manager.SubscriptionManagerInterfaceForManagers;
import org.apache.cxf.ws.eventing.base.SingletonSubscriptionManagerContainer;
import org.apache.cxf.ws.eventing.manager.AbstractSubscriptionManager;



/**
 * Simple Subscription Manager webservice for integration tests
 */
@WebService(endpointInterface = "org.apache.cxf.ws.eventing.manager.SubscriptionManagerEndpoint")
public class TestingSubscriptionManager extends AbstractSubscriptionManager {

    @Override
    protected SubscriptionManagerInterfaceForManagers getSubscriptionManagerBackend() {
        return SingletonSubscriptionManagerContainer.getInstance();
    }

}
